@font-face { font-family:'Barlow', sans-serif; src:url("'Barlow', sans-serif\\static\\'Barlow', sans-serif-Bold.ttf")； }
Sample information : $ID

Estimated number of cells
  The total number of barcodes identified as cells.
Median UMI counts per cell
  Among barcodes identified as cells, the median number of UMI per cell.
Median genes per cell
  The median number of genes per cell.
Mean reads per cell
  The mean number of reads per cell.

##### $estm_Num_cell

##### Estimated number of cell

##### $median_UMI_per_c

##### Median UMI counts per cell

##### $median_genes_per_c

##### Median genes per cell

##### $mean_r_per_c

##### Mean reads per cell

Beads to cells

(left) Beads to cells plot
  In library, different mRNAs from the same cell will carry the same cell barcode and random unique molecular identifiers (UMIs). However, some mRNA from dead cells mixed in reflection system was inevitability. This graph shows the distribution of UMI counts in each barcode. Barcodes can be determined to be cell-associated based on their UMI counts or by their expression profiles. Therefore, the graph contains both cell-associated (Colored Regions) and background-associated barcodes (Gray Regions).
(right) Histogram
  Histograms of number of beads per droplet.

$plot1
$plot3
Summary

Estimated number of cells
  The total number of barcodes identified as cells.
Mean reads per cell
  The mean number of reads detected per cell.
Mean UMI counts per cell
  The average number of UMI counts per cell. This item refers the average abundance of expression in each cell.
Median UMI counts per cell
  The median number of UMI counts per cell.
Total genes detected
  The total number of genes detected.
Mean genes per cell
  The mean number of genes detected per cell. This item refers the activity of gene expression in each cell.
Median genes per cell
  The median number of genes detected per cell.
Sequencing saturation
  The fraction of UMI originating from an already-observed UMI.
Fraction reads in cells
  The fraction of uniquely-mapped-to-transcriptome reads with cell-associated barcode.
Plot
  The distribution of nFeature and nCount in violin.

##### Sample name

$samplename

##### Species

$species

##### Estimated number of cells

$estm_Num_cell

##### Mean reads per cell

$mean_r_per_c

##### Mean UMI count per cell

$mean_UMI_per_c

##### Median UMI counts per cell

$median_UMI_per_c

##### Total genes detected

$total_gene

##### Mean genes per cell

$mean_genes_per_c

##### Median genes per cell

$median_genes_per_c

##### Fraction reads in cells

$Fraction

##### Sequencing saturation

$saturation
$plot4
Sequencing

Number of reads
  Number of raw off-machine reads obtained by this sequencing program.
Reads pass QC
  Number of reads after quality control (QC) that can be used for downstream analysis. QC includes filtering low quality reads and invalid barcodes.
Reads with exactly matched barcodes
  Number of reads with barcodes that match the barcode whitelist before correction.
Reads with failed barcodes
  Number of reads with invalid barcodes that fail to match the barcode whitelist.
Reads filtered on low quality
  Number of reads in low quality. The QC will filter the average base quality < Q20 or 2 bases < Q10 in the first 15 bases.
Q30 bases in cell barcode
  Fraction of cell barcode bases with Q-score ≥ 30.
Q30 bases in UMI
  Fraction of UMI bases with Q-score ≥ 30.
Q30 bases in reads
  Fraction of RNA read bases with Q-score ≥ 30.

##### mRNA

##### Number of reads

$cDNA_num_frag

##### Reads pass QC

$cDNA_frag_pass_QC

##### Reads with exactly matched barcodes

$cDNA_frag_exact_bar

##### Reads with failed barcodes

$cDNA_frag_fail_bar

##### Reads filtered on low quality

$cDNA_frag_low_qual

##### Q30 bases in cell barcode

$cDNA_Q30_c_bar

##### Q30 bases in UMI

$cDNA_Q30_UMI

##### Q30 bases in reads

$cDNA_Q30_r

##### Droplet index

##### Number of reads

$index_num_frag

##### Reads pass QC

$index_frag_pass_QC

##### Reads with exactly matched barcodes

$index_frag_exact_bar

##### Reads with failed barcodes

$index_frag_fail_bar

##### Reads filtered on low quality

$index_frag_low_qual

##### Q30 bases in cell barcode

$index_Q30_c_bar

##### Q30 bases in reads

$index_Q30_r
Mapping & Annotation

Reads pass QC
  Number of reads after quality control (QC) that can be used for downstream analysis. QC includes filtering low quality reads and invalid barcodes.
Reads mapped to genome
  Fraction of reads that mapped to the genome.
Plus strand
  The number of reads in plus strand.
Minus strand
  The number of reads in minus strand.
Mitochondria ratio
  The fraction of reads mapped to mitochondria.
Mapping quality corrected reads
  The number of reads that align to a single exonic locus but also align to 1 or more non-exonic loci.
Reads mapped to exonic regionse
  Fraction of reads that mapped to an exonic region of genome.
Reads mapped to intronic regions
  Fraction of reads that mapped to an intronic region of genome.
Reads mapped antisense to gene
  Fraction of reads mapped to transcriptome, but on the opposite strand of their annotated gene. This part of reads will be filtered out cause them are opposite to theoretical direction.
Reads mapped to intergenic regions
  Fraction of reads that mapped to intergenic regions of genome.

##### Reads pass QC

$raw_r

##### Reads mapped to genome

$r_m_geno

##### Plus strand

$plus_strd

##### Minus strand

$minus_strd

##### Mitochondria ratio

$mito_ratio

##### Mapping quality corrected reads

$map_qual_corrt_r

##### Reads mapped to exonic regions

$r_m_ex

##### Reads mapped to intronic regions

$r_m_intro

##### Reads mapped antisense to gene

$r_m_anti

##### Reads mapped to intergenic regions

$r_m_inter

##### Include introns

$intron_boolean
Cluster

Left
  This plot shows that the total UMI counts for each cell-barcode. Two-dimensional horizontal and vertical coordinates of each dot are obtained using the uniform manifold approximation and projection (UMAP) algorithm. Each dot represents a cell and is colored according to UMI counts. Cells with greater UMI counts likely have higher RNA content than cells with fewer ones.
Right
  The figure is automated clustering each cell-barcode by UMAP algorithm. The cells clustered into the same group have similar expression profiles. Each dot represents a cell, and is colored according to different cluster.

$plot2
$plot5
Marker

Table
  The table shows the top 30 differentially expressed genes for each cluster. Here a differential expression test was performed between each cluster and the rest of the sample for each gene. The p-value is a measure of the statistical significance of the expression difference, the smaller the P value, the closer to the theoretical value. Avg_log2FC is log fold-chage of the average expression between the markers for every cluster compared to all remaining cells.

$table
Cell Annotation

Predicated cell type
  The cell types for each of single cells from the human dataset were inferred by SingleR based on similarity to the Human Primary Cell Atlas (HPCA), for mouse dataset used by scMCA based on the person correlation with the Mouse Cell Atlas. UMAP plots of all cells colored by cell-type identity.The annotation results are just for reference only and are used to determine if the library quality is acceptable.

$plot8
Saturation

Left
  The plot shows the Sequencing Saturation metric as a function of downsampled sequencing depth in mean reads per cell, up to the observed sequencing depth. Sequencing Saturation is a measure of the observed library complexity, and approaches 1.0 (100%) when all converted mRNA transcripts have been sequenced. The slope of the curve near the endpoint can be interpreted as an upper bound to the benefit to be gained from increasing the sequencing depth beyond this point.
Right
  The plot shows the Median Genes per Cell as a function of downsampled sequencing depth in mean reads per cell, up to the observed sequencing depth. The slope of the curve near the endpoint can be interpreted as an upper bound to the benefit to be gained from increasing the sequencing depth beyond this point.

$plot6
$plot7